"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = require("path");
var utils_1 = require("../utils");
var maven_manager_1 = require("../managers/maven.manager");
var npm_manager_1 = require("../managers/npm.manager");
var schema_manager_1 = require("../managers/schema.manager");
var storage_manager_1 = require("../managers/storage.manager");
var ROOT = process.cwd();
var GenerateCommand = /** @class */ (function () {
    function GenerateCommand(options) {
        this.options = options;
    }
    GenerateCommand.prototype.generate = function (schema, skipModuleGeneration) {
        if (skipModuleGeneration === void 0) { skipModuleGeneration = false; }
        var outModuleDir = null;
        // Output module directory
        var projectBaseDirectory = '/';
        if (path_1.default.isAbsolute(this.options.outPath)) {
            outModuleDir = "" + this.options.outPath + projectBaseDirectory;
        }
        else {
            outModuleDir = ROOT + "/" + this.options.outPath + projectBaseDirectory;
        }
        // Kotlin group id
        var kotlinGroupId = this.options.groupId + ".kotlin";
        // Kotlin base directories
        var commonKtDir = outModuleDir + "/" + this.options.projectName + "-common";
        var commonJsDir = commonKtDir + "-js";
        var commonJvmDir = commonKtDir + "-jvm";
        if (!skipModuleGeneration) {
            utils_1.createDirectory(outModuleDir);
            maven_manager_1.default.createMavenProject(outModuleDir, commonKtDir, commonJsDir, commonJvmDir, this.options.projectName, kotlinGroupId, this.options.artifactId);
            npm_manager_1.default.createCommonJsPackageJson(commonJsDir, this.options.projectName);
        }
        var commonModuleBaseDir = "" + outModuleDir;
        if (!skipModuleGeneration) {
            commonModuleBaseDir = commonKtDir + "/src/main/kotlin/";
        }
        schema_manager_1.default.generateSchema(commonModuleBaseDir, kotlinGroupId, this.options.artifactId, schema);
        storage_manager_1.default.generateStorage(commonModuleBaseDir, kotlinGroupId, this.options.artifactId, schema);
    };
    return GenerateCommand;
}());
exports.default = GenerateCommand;
//# sourceMappingURL=generate.command.js.map